unit uBaseForm;

interface

uses
  Winapi.Windows, Winapi.Messages, System.SysUtils, System.Variants, System.Classes, Vcl.Graphics,
  Vcl.Controls, Vcl.Forms, Vcl.Dialogs, IniFiles, uSimpleParam;

type
  TBaseForm = class(TForm)
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure FormShow(Sender: TObject);
  private
    FIniFile: TIniFile;
    FSimpleParam: TSimpelParam;
  protected
    FAfterCreateHasExcuted: boolean;
  protected
    FFirstDisplay: boolean;
    procedure LoadParam; virtual;
    procedure SaveParam; virtual;
    procedure AfterCreate; virtual;
    property IniFile: TIniFile read FIniFile;
    property SimpleParam: TSimpelParam read FSimpleParam;
  public
    procedure ShowAsNormal; virtual;
  end;

const
  csMain = 'Main';

implementation

{$R *.dfm}

{ TBaseForm }
uses
  XwWindows;

procedure TBaseForm.AfterCreate;
begin
end;

procedure TBaseForm.FormCreate(Sender: TObject);
var
  sIniFileName: string;
begin
  FFirstDisplay := true;
  FAfterCreateHasExcuted := false;
  sIniFileName := ChangeFileExt(Application.ExeName, '.ini');
  FIniFile := TIniFile.Create(sIniFileName);
  FSimpleParam := TSimpelParam.Create;
  FSimpleParam.IniFile := FIniFile;
  FSimpleParam.LoadParams;
  LoadParam;
end;

procedure TBaseForm.FormDestroy(Sender: TObject);
begin
  SaveParam;
  FSimpleParam.SaveParams;
  FIniFile.Free;
  FSimpleParam.Free;
end;

procedure TBaseForm.FormShow(Sender: TObject);
begin
  if not FAfterCreateHasExcuted then
  begin
    FAfterCreateHasExcuted := true;
    AfterCreate;
  end;
end;

procedure TBaseForm.LoadParam;
begin
end;

procedure TBaseForm.SaveParam;
begin
end;

procedure TBaseForm.ShowAsNormal;
begin
  WindowState := wsNormal;
  BringToFront;
  SetXwForegroundWindow(self.Handle);
  show;
end;

end.
